@@ -32,7 +32,7 @@ class GeoToDo:
     __app_name__ = "GeoToDo"
     __version__ = "0.3.1"
     __context__ = "net.geo.GeoTodo"
-    glade_file = 'ui/GeoToDo.glade'    
+    glade_file = '/opt/geotodo/ui/GeoToDo.glade'    
   
     def __init__(self,controller,app,context):
         self.where_from_context = ["main"]
